# Generated by roxygen2: do not edit by hand

S3method(print,sbt_std_boot)
S3method(print,sbt_ustd_boot)
export(gg_hist_qq_boot)
export(gg_scatter_boot)
export(hist_qq_boot)
export(jab_after_boot)
export(parameterEstimates_boot)
export(scatter_boot)
export(standardizedSolution_boot)
export(store_boot)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(graphics,abline)
importFrom(graphics,hist)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(grid,arrow)
importFrom(grid,unit)
importFrom(patchwork,plot_spacer)
importFrom(patchwork,wrap_plots)
importFrom(rlang,.data)
importFrom(rlang,as_label)
importFrom(stats,approx)
importFrom(stats,density)
importFrom(stats,qqline)
importFrom(stats,qqnorm)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
