<!-- badges: start -->
[![Lifecycle: stable](https://img.shields.io/badge/lifecycle-stable-brightgreen.svg)](https://lifecycle.r-lib.org/articles/stages.html#stable)
[![Project Status: Active - The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![CRAN status](https://www.r-pkg.org/badges/version/semboottools?color=blue)](https://CRAN.R-project.org/package=semboottools)
[![CRAN: Release Date](https://www.r-pkg.org/badges/last-release/semboottools?color=blue)](https://cran.r-project.org/package=semboottools)
[![Code size](https://img.shields.io/github/languages/code-size/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools)
[![Last Commit at Main](https://img.shields.io/github/last-commit/Yangzhen1999/semboottools.svg)](https://github.com/Yangzhen1999/semboottools/commits/main)
[![R-CMD-check](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/Yangzhen1999/semboottools/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

(Version 0.1.2, updated on 2026-01-25, [release history](https://Yangzhen1999.github.io/semboottools/news/index.html))

# semboottools: Bootstrapping Helpers For Structural Equation Modelling

A collection of helper functions for
forming bootstrapping confidence
intervals and examining bootstrap
estimates in structural equation
modelling. An introduction to the
package can be found in the following
manuscript:

- Yang, W., & Cheung, S. F. (2026). Forming bootstrap confidence intervals and examining bootstrap distributions of standardized coefficients in structural equation modelling: A simplified workflow using the R package semboottools. *Behavior Research Methods, 58*(2), 38. <https://doi.org/10.3758/s13428-025-02911-z>

You can learn more about this package at the
[Github page](https://Yangzhen1999.github.io/semboottools/) of this
package.

An illustration of what this package can
do can be found in the following Get-Started
vignette:

<https://yangzhen1999.github.io/semboottools/articles/semboottools.html>

# Installation

Stable release versions of this package
can be installed from CRAN:

```r
install.packages("semboottools")
```

The latest developmental version of this
package can be installed by `remotes::install_github`:

```r
remotes::install_github("Yangzhen1999/semboottools")
```

# Issues

If you have any suggestions and found any
bugs, please feel free to open a GitHub
issue. Thanks.
